@@ -8,7 +8,10 @@
 # @param dtSim Incomplete simulated data.table
 # @return A data.frame column  with the updated simulated data
 
-getBinaryMean <- function(dtSim, formula, link) {
+getBinaryMean <- function(dtSim, formula, Size, link) {
+  
+  size <- with(dtSim, eval(parse(text = as.character(Size))))  
+  
 
   if (link=="logit") {
     logit <- with(dtSim, eval(parse(text = as.character(formula))))
@@ -17,15 +20,16 @@ getBinaryMean <- function(dtSim, formula, link) {
     p <- with(dtSim, eval(parse(text = as.character(formula))))
   }
 
-  return(p)
+  
+  return(list(p, size))
 
 }
 
-genbinom <- function(n,formula,link,dtSim) {
+genbinom <- function(n, formula, Size, link, dtSim) {
+  
+  params <- getBinaryMean(dtSim, formula, Size, link)
 
-  p <- getBinaryMean(dtSim, formula, link)
-
-  return(stats::rbinom(n, 1, p))
+  return(stats::rbinom(n, params[[2]], params[[1]]))
 
 }
 
